@@ -7,20 +7,16 @@
 #ifndef DBM_MULTIPLY_CPU_H
 #define DBM_MULTIPLY_CPU_H
 
-#include <stdbool.h>
-
-#include "dbm_multiply_internal.h"
+#include "dbm_internal.h"
 #include "dbm_shard.h"
 
 /*******************************************************************************
  * \brief Internal routine for executing the tasks in given batch on the CPU.
  * \author Ole Schuett
  ******************************************************************************/
-void dbm_multiply_cpu_process_batch(const int ntasks, dbm_task_t batch[ntasks],
-                                    const double alpha,
-                                    const dbm_pack_t *pack_a,
-                                    const dbm_pack_t *pack_b,
-                                    dbm_shard_t *shard_c);
+void dbm_multiply_cpu_process_batch(
+    const int ntasks, const dbm_task_t batch[ntasks], const double alpha,
+    const dbm_pack_t *pack_a, const dbm_pack_t *pack_b, dbm_shard_t *shard_c);
 
 #endif
 
